pub struct ClientSetting { /* private fields */ }Expand description
Settings used for creating a bitcoincore rpc client.
Implementations
Sourceimpl ClientSetting
impl ClientSetting
pub fn get_rpc_url(&self) -> &String
pub fn get_rpc_port(&self) -> &String
Usually resides in the datadir of your bitcoin setup (.bitcoin folder).
Sourcepub fn get_timeout_seconds(&self) -> &u64
pub fn get_timeout_seconds(&self) -> &u64
This is the time period in which the rpc connection stays alive despite not receiving a response from bitcoincore. It is important to set this high enough for creating a utxo set dump or scanning the utxo set takes more than the default 15 seconds.